"use strict";
//
// Copyright 2023 Signal Messenger, LLC.
// SPDX-License-Identifier: AGPL-3.0-only
//
Object.defineProperty(exports, "__esModule", { value: true });
const crypto_1 = require("crypto");
const Native = require("../../../Native");
const ByteArray_1 = require("../internal/ByteArray");
const Constants_1 = require("../internal/Constants");
const BackupAuthCredentialResponse_1 = require("./BackupAuthCredentialResponse");
class BackupAuthCredentialRequest extends ByteArray_1.default {
    constructor(contents) {
        super(contents, Native.BackupAuthCredentialRequest_CheckValidContents);
    }
    issueCredential(timestamp, receiptLevel, params) {
        const random = (0, crypto_1.randomBytes)(Constants_1.RANDOM_LENGTH);
        return this.issueCredentialWithRandom(timestamp, receiptLevel, params, random);
    }
    issueCredentialWithRandom(timestamp, receiptLevel, params, random) {
        return new BackupAuthCredentialResponse_1.default(Native.BackupAuthCredentialRequest_IssueDeterministic(this.contents, timestamp, receiptLevel, params.contents, random));
    }
}
exports.default = BackupAuthCredentialRequest;
//# sourceMappingURL=BackupAuthCredentialRequest.js.map